lcvtoolbox.core.schemas.CvatApiTaskAnnotations
==============================================

.. currentmodule:: lcvtoolbox.core.schemas

.. autoclass:: CvatApiTaskAnnotations
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CvatApiTaskAnnotations.__init__
      ~CvatApiTaskAnnotations.construct
      ~CvatApiTaskAnnotations.copy
      ~CvatApiTaskAnnotations.dict
      ~CvatApiTaskAnnotations.from_orm
      ~CvatApiTaskAnnotations.json
      ~CvatApiTaskAnnotations.model_construct
      ~CvatApiTaskAnnotations.model_copy
      ~CvatApiTaskAnnotations.model_dump
      ~CvatApiTaskAnnotations.model_dump_json
      ~CvatApiTaskAnnotations.model_json_schema
      ~CvatApiTaskAnnotations.model_parametrized_name
      ~CvatApiTaskAnnotations.model_post_init
      ~CvatApiTaskAnnotations.model_rebuild
      ~CvatApiTaskAnnotations.model_validate
      ~CvatApiTaskAnnotations.model_validate_json
      ~CvatApiTaskAnnotations.model_validate_strings
      ~CvatApiTaskAnnotations.parse_file
      ~CvatApiTaskAnnotations.parse_obj
      ~CvatApiTaskAnnotations.parse_raw
      ~CvatApiTaskAnnotations.schema
      ~CvatApiTaskAnnotations.schema_json
      ~CvatApiTaskAnnotations.update_forward_refs
      ~CvatApiTaskAnnotations.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CvatApiTaskAnnotations.model_computed_fields
      ~CvatApiTaskAnnotations.model_config
      ~CvatApiTaskAnnotations.model_extra
      ~CvatApiTaskAnnotations.model_fields
      ~CvatApiTaskAnnotations.model_fields_set
      ~CvatApiTaskAnnotations.version
      ~CvatApiTaskAnnotations.tags
      ~CvatApiTaskAnnotations.shapes
      ~CvatApiTaskAnnotations.tracks
   
   